@@ -23,11 +23,12 @@
 
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
-#include "gtkmm.h"
+#include <gtkmm.h>
 
 #include <glom/libglom/document/document_glom.h>
 #include <glom/libglom/connectionpool.h>
 #include <glom/libglom/appstate.h>
+#include <glom/libglom/data_structure/foundset.h>
 #include <glom/libglom/data_structure/privileges.h>
 #include <glom/libglom/data_structure/system_prefs.h>
 #include <glom/libglom/utils.h>
@@ -42,28 +43,9 @@ class LayoutItem_GroupBy;
 class LayoutItem_Summary;
 class LayoutItem_VerticalGroup;
 
-class FoundSet
-{
-public:
-  FoundSet();
-  FoundSet(const FoundSet& src);
-  FoundSet& operator=(const FoundSet& src);
-
-  bool operator==(const FoundSet& src) const;
-
-  Glib::ustring m_table_name;
-  Glib::ustring m_extra_join; // Only used for doubly-related related records (portals), in which case the WHERE clause is also slightly different.
-  Glib::ustring m_where_clause;
-  Glib::ustring m_extra_group_by;  // Only used for doubly-related related records (portals), in which case the WHERE clause is also slightly different.
-
-  ///field, ascending
-  typedef std::pair< sharedptr<const LayoutItem_Field>, bool> type_pair_sort_field;
-  typedef std::list<type_pair_sort_field> type_sort_clause;
-  type_sort_clause m_sort_clause;
-};
 
 /** A base class that is a Bakery View with some database functionality.
-*/
+ */
 class Base_DB :
   public View_Composite_Glom
 {
@@ -74,9 +56,6 @@ public:
   /// Specify the structure of what will be shown, and fill it.
   virtual bool init_db_details();
 
-  /// Specify what actual data will be shown:
-  virtual bool refresh_data_from_database();
-
   /** Returns whether we are in developer mode.
    * Some functionality will be deactivated when not in developer mode.
    */
@@ -98,8 +77,9 @@ public:
   static bool get_field_exists_in_database(const Glib::ustring& table_name, const Glib::ustring& field_name);
 
 
-  //This is const because const means not changing this instance, not whether we change the database.
   static Glib::RefPtr<Gnome::Gda::DataModel> query_execute(const Glib::ustring& strQuery, Gtk::Window* parent_window = 0);
+  static int count_rows_returned_by(const Glib::ustring& sql_query);
+
 
   bool add_standard_groups();
   bool add_standard_tables() const;
@@ -120,8 +100,8 @@ protected:
   sharedptr<LayoutItem_Field> offer_field_list(const sharedptr<const LayoutItem_Field>& start_field, const Glib::ustring& table_name, Gtk::Window* transient_for = 0);
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   sharedptr<LayoutItem_Field> offer_field_formatting(const sharedptr<const LayoutItem_Field>& start_field, const Glib::ustring& table_name, Gtk::Window* transient_for = 0);
-  sharedptr<LayoutItem_Text> offer_textobject(const sharedptr<LayoutItem_Text>& start_textobject, Gtk::Window* transient_for = 0);
-  sharedptr<LayoutItem_Image> offer_imageobject(const sharedptr<LayoutItem_Image>& start_imageobject, Gtk::Window* transient_for = 0);
+  sharedptr<LayoutItem_Text> offer_textobject(const sharedptr<LayoutItem_Text>& start_textobject, Gtk::Window* transient_for = 0, bool show_title = true);
+  sharedptr<LayoutItem_Image> offer_imageobject(const sharedptr<LayoutItem_Image>& start_imageobject, Gtk::Window* transient_for = 0, bool show_title = true);
   sharedptr<LayoutItem_Notebook> offer_notebook(const sharedptr<LayoutItem_Notebook>& start_notebook, Gtk::Window* transient_for = 0);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -144,6 +124,7 @@ protected:
   Glib::ustring get_find_where_clause_quick(const Glib::ustring& table_name, const Gnome::Gda::Value& quick_search) const;
 
 
+  //Methods to be overridden by derived classes:
   virtual void set_entered_field_data(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value&  value);
   virtual void set_entered_field_data(const Gtk::TreeModel::iterator& row, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
 
@@ -311,12 +292,14 @@ protected:
   bool check_entered_value_for_uniqueness(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value, Gtk::Window* parent_window);
   bool check_entered_value_for_uniqueness(const Glib::ustring& table_name, const Gtk::TreeModel::iterator& /* row */,  const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value, Gtk::Window* parent_window);
 
+  /** Fill the UI with information (data or structure, depending on the widget).
+   * Overridden by derived widgets to provide implementation.
+   */
   virtual bool fill_from_database();
-  virtual void fill_end(); //Call this from the end of fill_from_database() overrides.
 
   virtual void on_userlevel_changed(AppState::userlevels userlevel);
 
-  type_vecLayoutFields get_table_fields_to_show_for_sequence(const Glib::ustring& table_name, const Document_Glom::type_mapLayoutGroupSequence& mapGroupSequence) const;
+  type_vecLayoutFields get_table_fields_to_show_for_sequence(const Glib::ustring& table_name, const Document_Glom::type_list_layout_groups& mapGroupSequence) const;
   void get_table_fields_to_show_for_sequence_add_group(const Glib::ustring& table_name, const Privileges& table_privs, const type_vecFields& all_db_fields, const sharedptr<LayoutGroup>& group, type_vecLayoutFields& vecFields) const;
 
   /** Get the relationship into which the row button should navigate,
@@ -332,10 +315,9 @@ protected:
   static bool get_field_primary_key_index_for_fields(const type_vecFields& fields, guint& field_column);
   static bool get_field_primary_key_index_for_fields(const type_vecLayoutFields& fields, guint& field_column);
 
-
-
   static type_vecStrings util_vecStrings_from_Fields(const type_vecFields& fields);
 
+
   static void handle_error(const Glib::Exception& ex);
   static void handle_error(const std::exception& ex); //TODO_port: This is probably useless now.
   static bool handle_error();
